export interface LogOutput {
    /**
     * AWS request ID associated with the request. This is the ID returned to the client that called the invoke method.
     */
    'awsRequestId': string | undefined;
    /**
     * The id that came from the service that called this lambda.
     */
    'xRequestId': string;
    /**
     * The time this was logged in ticks.
     */
    '@timestamp': number;
    /**
     * The actual log message, please make this a non
     */
    'message': string;
    /**
     * The log level
     */
    'level': string;
    /**
     * Name of the Lambda function that is executing.
     */
    'functionName': string | undefined;
    /**
     * The Lambda function version that is executing. If an alias is used to invoke the function, then function_version will be the version the alias points to.
     */
    'functionVersion': string | undefined;
    /**
     * Time time that this lambda has been up.
     */
    'invokedFunctionArn': string | undefined;
    /**
     * Time time that this lambda has been up.
     */
    'memoryLimitInMB': number | undefined;
    /**
     * The name of the CloudWatch log group where you can find logs written by your Lambda function.
     */
    'logGroupName': string | undefined;
    /**
     * The name of the CloudWatch log group where you can find logs written by your Lambda function. The log stream may or may not change for each invocation of the Lambda function.
     * The value is null if your Lambda function is unable to create a log stream, which can happen if the execution role that grants necessary permissions to the Lambda function does not include permissions for the CloudWatch actions.
     */
    'logStreamName': string | undefined;
    /**
     * Time time remaining before this lambda execution shuts down.
     */
    'remainingTime': number | undefined;
    /**
     * The AWS account where this lambda was triggered.
     */
    'awsAccount': string | undefined;
    /**
     * The up time of this lambda.
     */
    'up': number;
    [x: string]: any;
}
